yakumo.base.Manager

Package yakumo :: Module base :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

    object --+
             |
            Manager

Known Subclasses:
  - GlanceV2Manager
  - , SubManager
  - , neutron.v2.port.Manager
  - , neutron.v2.router.Manager
  - , neutron.v2.floating_ip.Manager
  - , neutron.v2.subnet_pool.Manager
  - , neutron.v2.quota.Manager
  - , neutron.v2.security_group.Manager
  - , neutron.v2.network.Manager
  - , neutron.v2.subnet.Manager
  - , neutron.v2.lb.pool.Manager
  - , neutron.v2.lb.health_monitor.Manager
  - , neutron.v2.metering.label.Manager
  - , neutron.v2.metering.rule.Manager
  - , neutron.v2.vpn.service.Manager
  - , neutron.v2.vpn.ipsec_policy.Manager
  - , neutron.v2.vpn.ike_policy.Manager
  - , neutron.v2.vpn.ipsec_site_connection.Manager
  - , neutron.v2.lbaas.pool.Manager
  - , neutron.v2.lbaas.health_monitor.Manager
  - , neutron.v2.lbaas.load_balancer.Manager
  - , cinder.v1.volume_type.Manager
  - , cinder.v1.snapshot.Manager
  - , cinder.v1.volume.Manager
  - , cinder.v2.consistency_group_snapshot.Manager
  - , cinder.v2.volume.Manager
  - , cinder.v2.volume_transfer.Manager
  - , cinder.v2.volume_type.Manager
  - , cinder.v2.service.Manager
  - , cinder.v2.consistency_group.Manager
  - , cinder.v2.qos.Manager
  - , cinder.v2.volume_backup.Manager
  - , cinder.v2.quota_set.Manager
  - , cinder.v2.snapshot.Manager
  - , nova.v2.quota_set.Manager
  - , nova.v2.security_group_default_rule.Manager
  - , nova.v2.aggregate.Manager
  - , nova.v2.key_pair.Manager
  - , nova.v2.hypervisor.Manager
  - , nova.v2.agent.Manager
  - , nova.v2.floating_ip_dns.Manager
  - , nova.v2.fixed_ip.Manager
  - , nova.v2.certificate.Manager
  - , nova.v2.flavor.Manager
  - , nova.v2.floating_ip.Manager
  - , nova.v2.cloudpipe.Manager
  - , nova.v2.image.Manager
  - , nova.v2.network.Manager
  - , nova.v2.server_group.Manager
  - , nova.v2.service.Manager
  - , nova.v2.server.Manager
  - , nova.v2.availability_zone.Manager
  - , nova.v2.security_group.Manager
  - , nova.v2.floating_ip_bulk.Manager
  - , keystone.v2.service.Manager
  - , keystone.v2.endpoint.Manager
  - , keystone.v2.project.Manager
  - , keystone.v2.role.Manager
  - , keystone.v2.user.Manager
  - , keystone.v3.service.Manager
  - , keystone.v3.user.Manager
  - , keystone.v3.domain.Manager
  - , keystone.v3.endpoint.Manager
  - , keystone.v3.credential.Manager
  - , keystone.v3.project.Manager
  - , keystone.v3.group.Manager
  - , keystone.v3.role.Manager
  - , keystone.v3.region.Manager
  - , glance.v1.image.Manager

Base class for resource managers.

Instance Methods | [hide private]
yakumo.base.Manager |
__init__(self, client, verbose=False, **kwargs) Create a Manager object | source code
_no_such_api(self, *args) | source code
_json2attr(self, json_params) | source code
_attr2json(self, attrs) | source code
yakumo.base.Resource |
get_empty(self, id) Create a resource object without attributes | source code
yakumo.base.Resource |
create(self, **kwargs) Create a new resource | source code
yakumo.base.Resource |
get(self, id) Aquire an existing resource object | source code
_find_gen(self, **kwargs) | source code
yakumo.base.Resource |
find(self, **kwargs) Query existing resource object matched the conditions | source code
yakumo.base.Resource |
find_one(self, **kwargs) Aquire an existing resource object matched the conditions | source code
[yakumo.base.Resource] |
list(self) Aquire an existing resource object | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| resource_class = `None`
| service_type = ``'````'``
| _attr_mapping = ``[``]``
| _has_detail = `True`
| _has_extra_attr = `False`
| _hidden_methods = `None`
| _json_resource_key = ``'````'``
| _json_resources_key = ``'````'``
| _id_attr = ``'``id``'``
| _update_method = ``'``put``'``
| _url_resource_path = ``'````'``
| _url_resource_list_path = ``'````'``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, client, verbose=False, **kwargs) (Constructor) | source code
Create a Manager object kwargs: options Parameters: `client` (yakumo.Client) - client object `verbose` (bool) - Whether str(Resource) displays all attributes Returns: yakumo.base.Manager Manager object Overrides: object.__init__

### get_empty(self, id) | source code
Create a resource object without attributes Returns: yakumo.base.Resource Resource object (empty)

### create(self, **kwargs) | source code
Create a new resource kwargs: attributes of the resource Returns: yakumo.base.Resource Resource object (empty)

### get(self, id) | source code
Aquire an existing resource object Parameters: `id` (str) - ID Returns: yakumo.base.Resource Resource object

### find(self, **kwargs) | source code
Query existing resource object matched the conditions kwargs is key=value style query conditions. Returns empty list if no matched resource. Returns: yakumo.base.Resource List of Resource object

### find_one(self, **kwargs) | source code
Aquire an existing resource object matched the conditions kwargs is key=value style query conditions. Returns None if no matched resource. Returns: yakumo.base.Resource Resource object

### list(self) | source code
Aquire an existing resource object Returns: [yakumo.base.Resource] List of Resource objects